@@ -20,7 +20,8 @@ script_name = command_args.script_name
 def restart(args=None):
     kill_str = f'''ps -aux|grep {script_name} |grep -v grep|awk '{{print $2}}' |xargs kill -9;'''
     subprocess.getstatusoutput('git pull')
-    threading.Thread(target=os.system, args=(kill_str + start_shell_str,)).start()
+    os.system(kill_str)
+    threading.Thread(target=os.system, args=(start_shell_str,)).start()
     while True:
         time.sleep(20)
         try:
@@ -35,7 +36,8 @@ def restart(args=None):
             break
         # subprocess.getstatusoutput(cmd_str)
         print('git内容更新了，执行语句：', kill_str, start_shell_str)
-        threading.Thread(target=os.system, args=(kill_str + start_shell_str,)).start()
+        os.system(kill_str)
+        threading.Thread(target=os.system, args=(start_shell_str,)).start()
 
 
 if __name__ == '__main__':
